@@ -1,3 +1,25 @@
+/*
+ * AT-SPI - Assistive Technology Service Provider Interface
+ * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
+ *
+ * Copyright 2001 Sun Microsystems Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <cspi/spi-private.h>
 
 /**
@@ -70,7 +92,7 @@ AccessibleHyperlink_getURI (AccessibleHyperlink *obj,
 
   retval =
     Accessibility_Hyperlink_getURI (CSPI_OBJREF (obj),
-				    (CORBA_long) i, cspi_ev ());
+				    i, cspi_ev ());
 
   cspi_return_val_if_ev ("getURI", NULL);
 
@@ -95,7 +117,7 @@ AccessibleHyperlink_getObject (AccessibleHyperlink *obj,
 
   return cspi_object_add (
     Accessibility_Hyperlink_getObject (CSPI_OBJREF (obj),
-				       (CORBA_long) i, cspi_ev ()));
+				       i, cspi_ev ()));
 }
 
 /**
@@ -115,14 +137,17 @@ AccessibleHyperlink_getIndexRange (AccessibleHyperlink *obj,
                                    long int *startIndex,
                                    long int *endIndex)
 {
+  CORBA_long si, ei;
+
   cspi_return_if_fail (obj != NULL);
 
-  *startIndex = (long)
-    Accessibility_Hyperlink__get_startIndex (CSPI_OBJREF (obj), cspi_ev ());
-  *endIndex = (long)
-    Accessibility_Hyperlink__get_endIndex (CSPI_OBJREF (obj), cspi_ev ());
+si = Accessibility_Hyperlink__get_startIndex (CSPI_OBJREF (obj), cspi_ev ());
+ cspi_return_if_ev ("startIndex");
+ ei = Accessibility_Hyperlink__get_endIndex (CSPI_OBJREF (obj), cspi_ev ());
 
-  cspi_return_if_ev ("getIndexRange");
+ cspi_return_if_ev ("endIndex");
+ *startIndex = si;
+ *endIndex = ei; 
 }
 
 /**
