@@ -42,7 +42,6 @@
  *
  *            object:property-change
  *            object:property-change:accessible-name
- *            object:property-change:accessible-state
  *            object:property-change:accessible-description
  *            object:property-change:accessible-parent
  *            object:property-change:accessible-value
@@ -56,6 +55,7 @@
  *
  *    (other object events)
  *
+ *            object:state-changed 
  *            object:children-changed
  *            object:visible-data-changed
  *            object:selection-changed
@@ -80,8 +80,8 @@
  *            window:reparent
  *            window:desktop-create
  *            window:desktop-destroy
- *            window:focus-in
- *            window:focus-out
+ *            window:activate
+ *            window:deactivate
  *            window:raise
  *            window:lower
  *            window:move
@@ -104,8 +104,6 @@ SPIBoolean
 SPI_registerGlobalEventListener (AccessibleEventListener *listener,
 				 const char              *eventType)
 {
-  SPIBoolean retval;
-
   if (!listener)
     {
       return FALSE;
@@ -116,9 +114,7 @@ SPI_registerGlobalEventListener (AccessibleEventListener *listener,
     cspi_event_listener_get_corba (listener),
     eventType, cspi_ev ());
 
-  retval = !cspi_exception ();
- 
-  return retval;
+  return  !cspi_exception ();
 }
 
 /**
@@ -172,7 +168,7 @@ SPI_deregisterGlobalEventListener (AccessibleEventListener *listener,
   Accessibility_Registry_deregisterGlobalEventListener (
     cspi_registry (), 
     cspi_event_listener_get_corba (listener),
-    (CORBA_char *) eventType, cspi_ev ());
+    eventType, cspi_ev ());
 
   return !cspi_exception ();
 }
@@ -214,7 +210,7 @@ SPI_getDesktop (int i)
 {
   return cspi_object_add (
     Accessibility_Registry_getDesktop (
-      cspi_registry (), (CORBA_short) i, cspi_ev ()));
+      cspi_registry (), i, cspi_ev ()));
 }
 
 /**
@@ -248,7 +244,7 @@ SPI_getDesktopList (Accessible ***desktop_list)
   desktops = Accessibility_Registry_getDesktopList (cspi_registry (),
 						    cspi_ev ());
 
-  cspi_return_val_if_ev ("getting desktop list", 0);
+  cspi_return_val_if_ev ("getDesktopList", 0);
 
   list = g_new0 (Accessible *, desktops->_length + 1);
 
@@ -285,6 +281,12 @@ SPI_freeDesktopList (Accessible **desktop_list)
   g_free (desktop_list);
 }
 
+/**
+ * SPI_KEYSET_ALL_KEYS:
+ * @SPI_KEYSET_ALL_KEYS: A special value for an AccessibleKeySet type, which tacitly
+ *                       includes all keycodes and keyvals for the specified modifier set.
+ **/
+
 /**
  * SPI_registerAccessibleKeystrokeListener:
  * @listener:  a pointer to the #AccessibleKeystrokeListener for which
@@ -340,10 +342,16 @@ SPI_registerAccessibleKeystrokeListener (AccessibleKeystrokeListener  *listener,
       key_set._buffer = Accessibility_KeySet_allocbuf (keys->len);
       for (i = 0; i < key_set._length; ++i)
         {
-          /* we overload the keyset long w/keycodes, the - bit acts as a flag */
-          key_set._buffer[i] = (keys->keysyms[i]) ? keys->keysyms[i] :
-		                                  - keys->keycodes[i];
-	  /* fprintf (stderr, "key-set %d = %d\n", i, (int) key_set->_buffer[i]); */
+          key_set._buffer[i].keycode = keys->keycodes[i];
+	  key_set._buffer[i].keysym = keys->keysyms[i];
+	  if (keys->keystrings && keys->keystrings[i]) 
+	    {
+	      key_set._buffer[i].keystring = keys->keystrings[i];
+	    } 
+          else 
+            {
+	      key_set._buffer[i].keystring = CORBA_string_dup("");
+	    }
         }
     }
   else
